@@ -1,16 +1,21 @@
 import jtorch
 import jittor as jt
 
-from jtorch import make_module, Tensor
+from jtorch import make_module, Tensor, ModuleMisc
 
 for k,v in jt.nn.__dict__.items():
     if isinstance(v, type) and issubclass(v, jt.Module):
         globals()[k] = make_module(v)
+    elif callable(v):
+        globals()[k] = v
 
-class Module(jt.Module):
+class Module(ModuleMisc, jt.Module):
     def __call__(self, *args, **kw):
         return self.forward(*args, **kw)
 
+    def execute(self, *args, **kw):
+        return self.forward(*args, **kw)
+
     def to(self, device):
         ''' do nothing but return its self'''
         return self
